>From 9432a9bad13150fc1b03042d412c7bc3c9d50157 Mon Sep 17 00:00:00 2001
From: Tadas Slotkus <devtadas@gmail.com>
Date: Sun, 21 Aug 2011 16:27:22 +0300
Subject: [carFl mem 59/65] Move superios[] array to globals

Now in globals structure:
struct superio superios[];

Signed-off-by: Tadas Slotkus <devtadas@gmail.com>
---
 flash.h      |    9 +++++++++
 internal.c   |    6 +-----
 it87spi.c    |   10 +++++-----
 programmer.h |    6 ------
 4 files changed, 15 insertions(+), 16 deletions(-)

diff --git a/flash.h b/flash.h
index 29282c0..c1fa60c 100644
--- a/flash.h
+++ b/flash.h
@@ -286,6 +286,12 @@ enum programmer {
 	PROGRAMMER_INVALID /* This must always be the last entry. */
 };
 
+struct superio {
+	uint16_t vendor;
+	uint16_t port;
+	uint16_t model;
+};
+
 #define TMP_BUF_SIZE 60
 
 struct globals {
@@ -314,6 +320,9 @@ struct globals {
 
 	/* Is writing allowed with this programmer? */
 	int programmer_may_write;
+
+	#define SUPERIO_MAX_COUNT 3
+	struct superio superios[SUPERIO_MAX_COUNT];
 };
 void init_globals(globals *g);
 
diff --git a/internal.c b/internal.c
index 22c77eb..e12c60c 100644
--- a/internal.c
+++ b/internal.c
@@ -107,15 +107,11 @@ void probe_superio(globals *g)
 #endif
 }
 
-#define SUPERIO_MAX_COUNT 3
-
-struct superio superios[SUPERIO_MAX_COUNT];
-
 int register_superio(globals *g, struct superio s)
 {
 	if (g->superio_count == SUPERIO_MAX_COUNT)
 		return 1;
-	superios[g->superio_count++] = s;
+	g->superios[g->superio_count++] = s;
 	return 0;
 }
 
diff --git a/it87spi.c b/it87spi.c
index d853e29..42f4c4d 100644
--- a/it87spi.c
+++ b/it87spi.c
@@ -206,10 +206,10 @@ int init_superio_ite(globals *g)
 	int i, ret = 0;
 
 	for (i = 0; i < g->superio_count; i++) {
-		if (superios[i].vendor != SUPERIO_VENDOR_ITE)
+		if (g->superios[i].vendor != SUPERIO_VENDOR_ITE)
 			continue;
 
-		switch (superios[i].model) {
+		switch (g->superios[i].model) {
 		case 0x8500:
 		case 0x8502:
 		case 0x8510:
@@ -223,17 +223,17 @@ int init_superio_ite(globals *g)
 			//it85xx_spi_init(superios[i]);
 			break;
 		case 0x8705:
-			ret |= it8705f_write_enable(g, superios[i].port);
+			ret |= it8705f_write_enable(g, g->superios[i].port);
 			break;
 		case 0x8716:
 		case 0x8718:
 		case 0x8720:
-			ret |= it87spi_probe(g, superios[i].port);
+			ret |= it87spi_probe(g, g->superios[i].port);
 			break;
 		default:
 			msg_pdbg("Super I/O ID 0x%04hx is not on the list of "
 				 "flash capable controllers.\n",
-				 superios[i].model);
+				 g->superios[i].model);
 		}
 	}
 	return ret;
diff --git a/programmer.h b/programmer.h
index cf84a00..8d87719 100644
--- a/programmer.h
+++ b/programmer.h
@@ -210,12 +210,6 @@ void dmi_init(globals *g);
 int dmi_match(globals *g, const char *pattern);
 
 /* internal.c */
-struct superio {
-	uint16_t vendor;
-	uint16_t port;
-	uint16_t model;
-};
-extern struct superio superios[];
 #define SUPERIO_VENDOR_NONE	0x0
 #define SUPERIO_VENDOR_ITE	0x1
 #endif
-- 
1.7.6

